Literature
==========

Below is a list of references that are cited in the ``emicroml`` documentation:

.. [Ricolleau1] |nbspc|"Random vs realistic amorphous carbon models for high
		       resolution microscopy and electron diffraction",
		       C. Ricolleau *et al.*, J. Appl. Phys. **114**, 21 (2013),
		       :doi:`10.1063/1.4831669`

.. [Boothroyd1] |nbspc|"Quantification of high-resolution electron microscope
		       images of amorphous carbon", C.B. Boothroyd,
		       Ultramicroscopy **83**, 3-4 (2000),
		       :doi:`10.1016/S0304-3991(00)00012-7`

.. [Schonfeld1] |nbspc|"Anisotropic mean-square displacements (MSD) in
		       single-crystals of 2*H*- and 3*R*-:math:`\text{MoS}_2`",
		       B. Schönfeld et al., Acta Cryst. **83**, 404-407 (1983),
		       :doi:`10.1107/S0108768183002645`

.. [Mahr1] |nbspc|"Influence of distortions of recorded diffraction patterns on
	          strain analysis by nano-beam electron diffraction",
		  C. Mahr et al., Ultramicroscopy **196**, 74-82 (2019),
		  :doi:`10.1016/j.ultramic.2018.09.010`

.. [Hawkes1] |nbspc|"Principles of Electron Optics, Volume One: Basic
	            Geometrical Optics", P. Hawkes and E. Kasper, Academic Press
		    (2018),
		    :doi:`10.1016/C2015-0-06653-9`

.. [Fitzpatrick1] |nbspc|"Calibration-sample free distortion correction of
		         electron diffraction patterns using deep learning",
			 M.R.C. Fitzpatrick *et al.*, Ultramicroscopy **283**,
			 114347 (2026), :doi:`10.1016/j.ultramic.2026.114347`

.. |nbspc| unicode:: U+00A0 .. non-breaking space
